@@ -45,9 +45,9 @@ class BottleDefectConfig(BaseConfig):
 
     index_to_category: Optional[Dict[int, str]] = field(
         default_factory=lambda: {
-           0: "caps",
-           1: "HDPE",
-           2: "PET",
+            0: 'HDPE', 
+            1: 'caps', 
+            2: 'PET'
         }
     )
 
