@@ -714,7 +714,7 @@ class SolarPanelUseCase(BaseProcessor):
                 "confidence": det.get("confidence", 0.0),
                 "bounding_box": det.get("bounding_box", {})
             }
-            for det in detections if det.get("category", "unknown") == "cracked"
+            for det in detections
         ]
 
     def _generate_summary(self, summary: dict, alerts: List) -> str:
